@@ -39,7 +39,7 @@ CocaineGroup = "Cocaine"
 ActionGroup = "Actions"
 
 POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop', 'listing', 'undeploy', 'info')
-API_VERSION = 1.1
+API_VERSION = 1.2
 
 
 class Dispatcher(object):
@@ -96,6 +96,10 @@ define('username', group=CocaineGroup,
        help='username',
        type=str)
 
+define('wildcard', group=CocaineGroup,
+       help='wildcard', default='*',
+       type=str)
+
 # CocaineGroup
 define('host', group=CocaineGroup,
        help='Host of buildfarm locator',
@@ -215,15 +219,20 @@ def undeploy():
 
 @Dispatcher.attach("listing")
 def listing():
-    log.info("Fetching a list of your applications")
+    log.info("Fetching a list of your applications according to wildcard %s",
+             options.wildcard)
     try:
         s = Service("flow@main", host=options.host, port=options.port)
+        task = {}
+        if options.wildcard:
+            task["wildcard"] = options.wildcard
         apps = s.enqueue("list",
-                         gen_task(None)).get()
-        print("User\t\t\tApplication\t\t\tVersion")
-        for app, version in (item.rsplit('_', 1) for item in apps):
+                         gen_task(task)).get()
+        # ToDo: Make it pretty
+        for app, status in apps.iteritems():
             user, appname = app.split('_', 1)
-            print(user, '\t\t', app, '\t\t', version)
+            appname, version = appname.rsplit('_', 1)
+            print(user, '\t', appname, '\t\t', version, '\t\t', status)
     except Exception as err:
         log.error(err)
         exit(1)
